
*--------------------------------------------------------
* 1. Exclude hhs with missing values
*--------------------------------------------------------
/*
Households with missing values (flag variables equal to ‐1) in at least one of the material
deprivation items are excluded from the calculation (these are the missings in rx060)
*/

gen cases_excl = 1
replace cases_excl =0 if hs011_f !=-1 & ///
hs021_f !=-1 & hs031_f != -1 &  ///
hs040_f != -1 & hs050_f != -1 & hs060_f != -1 & ///
hs110_f != -1 & hh050_f != -1 & pd080_f != -1 & ///
hd080_f != -1 & pd020_f != -1 & pd030_f != -1 & ///
pd070_f != -1 & pd060_f != -1 & pd050_f != -1 

count if cases_excl==1
count if rx060==.

*--------------------------------------------------------
* 2. Compute deprivations
*--------------------------------------------------------
/*
Compute 13 dichotomous material deprivation items with 1 = deprived, 0 = not deprived

Note: in the case of arrears (hs011, hs021, hs031) the dichotomous variable will take the value 1
for any type of arrear (deprived in at least 1); in the case of internet, furniture, clothes, shoes,
small money, leisure and friends values 2 and 3 are recoded 0 
(that is, a person is deprived only if cannot afford because of money, and not because of other reason)
*/

gen arrears_morgrent = hs011<=2 if hs011!=.
gen arrears_util = hs021<=2 if hs021!=.
gen arrears_hirepurch = hs031<=2 if hs031!=.
gen housing = 1 if (arrears_morgrent==1 | arrears_util==1 | arrears_hirepurch==1) 
replace housing = 0 if (hs011_f == -2) & (hs021_f == -2) & (hs031_f == -2)
gen holiday  = hs040==2 if hs040!=.
gen protmeal = hs050==2 if hs050!=.
gen unexpfexp = hs060==2 if hs060!=.
gen car = (hs110!=1 & hs110!=3) if hs110!=.
gen warm = hh050==2 if hh050!=.
gen internet = (pd080!=1 & pd080!=3) if pd080!=.
gen furniture = (hd080!=1 & hd080!=3) if hd080!=.
gen clothes = (pd020!=1 & pd020!=3) if pd020!=.
gen shoes = (pd030!=1 & pd030!=3) if pd030!=.
gen small_money  = (pd070!=1 & pd070!=3) if pd070!=.
gen leisure = (pd060!=1 & pd060!=3) if pd060!=.
gen friends = (pd050!=1 & pd050!=3) if pd050!=.


*--------------------------------------------------------
* 3. Compute number of deprivations
*--------------------------------------------------------
/*
Compute a new variable which sums up the 13 deprivations
*/

egen n_deprivations = rowtotal(housing-friends),missing
replace n_deprivations=. if cases_excl==1

tab n_deprivations


*--------------------------------------------------------
* 4. Compute the MD indicator for adults
*--------------------------------------------------------

/*
Compute a material deprivation indicator= 1 (deprived) if n_deprivations greater equal 7; =
0 (not deprived) if n_deprivations less 7
*/

// MD for individuals >= 16
gen mat_deprived=.
replace mat_deprived= 1 if (n_deprivations >=7 & n_deprivations ~= .) & age>=16
replace mat_deprived= 0 if (n_deprivations < 7) & age>=16

// check for individuals >= 16
tab mat_deprived if age>=16
tab rx060 if age>=16


*--------------------------------------------------------
* 5. Compute the MD indicator for children
*--------------------------------------------------------
/*
Re-compute for children: individual items are only collected for people aged 16 or over and have
therefore to be estimated for children below 16. The rule is the following:
“if at least half the number of adults for which the information is available in the household lack an item, then the children living in
that household are considered as deprived from that item”. 
The same set of 13 items and the same threshold is used for both children and adults. 
However, when computing deprivation with regards to children, a lower weight is
given to adult items, in order to avoid making the indicator of children too sensitive to adult deprivations; among the
deprivations required to be considered as deprived, at least three need to be household deprivations (out of the
seven household deprivations items included in the list). Hence, when the 13-item indicator is broken down for children
*/
 
// number of household-level deprivations
egen child_n_deprivations_hh = rowtotal(unexpfexp housing holiday protmeal warm car furniture) if age<16,missing
replace child_n_deprivations_hh=. if cases_excl==1 & age<16

// number of adults deprived in...
bys hhid_cy: egen n_internet_hh = total(internet) 
bys hhid_cy: egen n_adults_internet = count(internet) 		// number of adults for which the information is available (not missing)

// child deprived
gen child_internet = 1 if (n_internet_hh >= n_adults_internet*0.5) & n_adults_internet!=0 & age<16

// number of adults deprived in...
bys hhid_cy: egen n_clothes_hh = total(clothes) 
bys hhid_cy: egen n_adults_clothes = count(clothes) 

// child deprived
gen child_clothes = 1 if (n_clothes_hh >= n_adults_clothes*0.5)  & n_adults_clothes!=0 & age<16

// number of adults deprived in...
bys hhid_cy: egen n_shoes_hh = total(shoes) 
bys hhid_cy: egen n_adults_shoes = count(shoes) 

// child deprived
gen child_shoes = 1 if (n_shoes_hh >= n_adults_shoes*0.5)  & n_adults_shoes!=0 & age<16

// number of adults deprived in...
bys hhid_cy: egen n_small_money_hh = total(small_money) 
bys hhid_cy: egen n_adults_small_moneys = count(small_money) 

// child deprived
gen child_small_money = 1 if (n_small_money_hh >= n_adults_small_moneys*0.5)  & n_adults_small_moneys!=0 & age<16

// number of adults deprived in...
bys hhid_cy: egen n_leisure_hh = total(leisure) 
bys hhid_cy: egen n_adults_leisure = count(leisure) 

// child deprived
gen child_leisure = 1 if (n_leisure_hh >= n_adults_leisure*0.5)  & n_adults_leisure!=0 & age<16

// number of adults deprived in...
bys hhid_cy: egen n_friends_hh = total(friends) 
bys hhid_cy: egen n_adults_friends = count(friends) 

// child deprived
gen child_friends = 1 if (n_friends_hh >= n_adults_friends*0.5)  & n_adults_friends!=0 & age<16

// number of deprivations (out of 13)
egen n_deprivations_child = rowtotal(unexpfexp housing holiday protmeal warm car furniture child_internet child_clothes child_shoes child_small_money child_leisure child_friends),missing
replace n_deprivations_child=. if cases_excl==1


// MD for children
replace mat_deprived = 0 if  age<16
replace mat_deprived = 1 if (n_deprivations_child >=7 & child_n_deprivations_hh>=3) & age<16

replace mat_deprived=. if rx060==.

// checks
bys code: tabstat mat_deprived rx060, stats(mean) 
bys code: tabstat mat_deprived rx060 [aw=wgt_ind], stats(mean) 




		