
*===============================================================================
*===============================================================================
* Chronic Poverty in Bulgaria, with a focus on the Roma population
*===============================================================================
*===============================================================================


*--------------------------------------------------------
* 1) Import from .csv and save data as .dta
*--------------------------------------------------------

*Define the modules needed (2021=T panel)
foreach mod in H P R D {
clear 

*First, import the dataset .csv to .dta format
clear
cap import delimited "$rawlong/UDB_lBG21`mod'.csv", case(upper) asdouble stringcols(2 4) 

rename *, lower

save "$createddata/UDB_lBG21`mod'.dta", replace
}


*--------------------------------------------------------
* 2) Merge the longuitudinal modules 
*--------------------------------------------------------

* D file (hh-level): with rotational group info
use "$createddata\UDB_lBG21D", clear

// gen relevant variables
gen year=db010
gen hid=db030
gen r_group=db075												// rotation group (only in D file)

sort year hid

// hh id and year for the merge (same as in H file and R file)
clonevar hb030=db030 				// hh id in H
clonevar hb010=db010				// year in H

clonevar rb040=db030 				// hh id in R
clonevar rb010=db010			    	// year in R

// merge D file (hh-level) with H file (hh-level)  
merge 1:1 hb010 hb030 using "$createddata/UDB_lBG21H.dta"
keep if _merge==3  																										
drop _merge

// merge with R file (individual-level)
merge 1:m rb010 rb040 using "$createddata/UDB_lBG21R.dta"
keep if _merge==3  																									
drop _merge

clonevar pb010=hb010			// year in P
clonevar pb030=rb030				// person id in P
clonevar px030=db030			// hh id in P

// merge with P file (individual-level)
merge 1:1 pb010 px030 pb030 using "$createddata/UDB_lBG21P.dta"
drop _merge

clonevar pid = rb030 
sort hid pid year
order year hid pid
format pid %10.0f

// duplicates
duplicates tag rb010 rb020 rb030, g(dup)			   // year, country, personal id
sort rb010 rb020 rb030 rb040
by rb010 rb020 rb030: g N=_n
drop if N==2 
drop if N==1 & dup==1
drop dup


*Save the dataset
save "$createddata/SILC_Panel_BG21.dta", replace


*********************************************
// Use constructed data-set
use "$createddata/SILC_Panel_BG21", clear
*********************************************

*--------------------------------------------------------
* 3) Persistent AROP
*--------------------------------------------------------

// keep groups observed for 4 years
tab year r_group
keep if r_group==2 | r_group==5 | r_group==6 	
tab year r_group

// keep a balanced panel
gen aux = 1
bys hid pid: egen n_years = sum(aux)
tab n_years
keep if n_years==4 
drop aux

// 'Not current household members' are excluded (RB110>4)
tab rb110

// people with missing values for equivalised income are excluded
inspect hx090
summ hx090

// rb064: Longitudinal weight (four-year duration)
bys hid pid: egen wgt_long = min(rb064)

// tag individuals
egen person = tag(hid pid) 
tab person															

// male
gen male = 0
replace male = 1 if pb150==1

// Include poverty lines (taken from cross-section, lines that reproduce arop in each T)
gen pline = .
replace pline = 3094 if year==2021
replace pline = 2767 if year==2020
replace pline = 2534 if year==2019
replace pline = 2154 if year==2018

// Poverty status in each year
gen arop_2021 = . if year==2021
replace arop_2021 = 1 if hx090<pline & year==2021
replace arop_2021 = 0 if hx090>=pline & year==2021

gen arop_2020 = . if year==2020
replace arop_2020 = 1 if hx090<pline & year==2020
replace arop_2020 = 0 if hx090>=pline & year==2020

gen arop_2019 = . if year==2019
replace arop_2019 = 1 if hx090<pline & year==2019
replace arop_2019 = 0 if hx090>=pline & year==2019

gen arop_2018 = . if year==2018
replace arop_2018 = 1 if hx090<pline & year==2018
replace arop_2018 = 0 if hx090>=pline & year==2018

// hoy many periods the person was AROP (excluding the current)
egen n_arop_aux = rowtotal(arop_2018 arop_2019 arop_2020), missing
bys hid pid: egen n_arop = sum(n_arop_aux)
drop n_arop_aux

// if the person is arop in the current year
bys hid pid: egen arop_t = sum(arop_2021)

// persistent arop 
gen persistent_arop = 0
replace persistent_arop = 1 if n_arop>=2 & arop_t==1

// persistent arop rate
tabstat persistent_arop [aw=wgt_long] if person==1, stats(mean) 


*--------------------------------------------------------
* 4) Persistent Material Deprivation
*--------------------------------------------------------

** MATERIAL DEPRIVATION **
 
// hh id by year
egen hhid_y = group(hid year) 

// age 
 gen age=year-rb080	
 tab age
 
// exclude missings
gen cases_excl = 1
replace cases_excl =0 if hs011_f !=-1 & ///
hs021_f !=-1 & hs031_f != -1 &  ///
hs040_f != -1 & hs050_f != -1 & hs060_f != -1 & ///
hs110_f != -1 & hh050_f != -1 & pd080_f != -1 & ///
hd080_f != -1 & pd020_f != -1 & pd030_f != -1 & ///
pd070_f != -1 & pd060_f != -1 & pd050_f != -1 

count if cases_excl==1

// compute deprivations
gen arrears_morgrent = hs011<=2 if hs011!=.
gen arrears_util = hs021<=2 if hs021!=.
gen arrears_hirepurch = hs031<=2 if hs031!=.
gen housing = 1 if (arrears_morgrent==1 | arrears_util==1 | arrears_hirepurch==1) 
replace housing = 0 if (hs011_f == -2) & (hs021_f == -2) & (hs031_f == -2)
gen holiday  = hs040==2 if hs040!=.
gen protmeal = hs050==2 if hs050!=.
gen unexpfexp = hs060==2 if hs060!=.
gen car = (hs110!=1 & hs110!=3) if hs110!=.
gen warm = hh050==2 if hh050!=.
gen internet = (pd080!=1 & pd080!=3) if pd080!=.
gen furniture = (hd080!=1 & hd080!=3) if hd080!=.
gen clothes = (pd020!=1 & pd020!=3) if pd020!=.
gen shoes = (pd030!=1 & pd030!=3) if pd030!=.
gen small_money  = (pd070!=1 & pd070!=3) if pd070!=.
gen leisure = (pd060!=1 & pd060!=3) if pd060!=.
gen friends = (pd050!=1 & pd050!=3) if pd050!=.

// number of deprivations
egen n_deprivations = rowtotal(housing-friends),missing
replace n_deprivations=. if cases_excl==1

// MD for individuals >= 16
gen mat_deprived=.
replace mat_deprived= 1 if (n_deprivations >=7 & n_deprivations ~= .) & age>=16
replace mat_deprived= 0 if (n_deprivations < 7) & age>=16

// MD for children

* number of household-level deprivations
egen child_n_deprivations_hh = rowtotal(unexpfexp housing holiday protmeal warm car furniture) if age<16,missing
replace child_n_deprivations_hh=. if cases_excl==1 & age<16

* internet
bys hhid_y: egen n_internet_hh = total(internet) 
bys hhid_y: egen n_adults_internet = count(internet) 		// number of adults for which the information is available (not missing)
gen child_internet = 1 if (n_internet_hh >= n_adults_internet*0.5) & n_adults_internet!=0 & age<16

* clothes
bys hhid_y: egen n_clothes_hh = total(clothes) 
bys hhid_y: egen n_adults_clothes = count(clothes) 
gen child_clothes = 1 if (n_clothes_hh >= n_adults_clothes*0.5)  & n_adults_clothes!=0 & age<16

* shoes
bys hhid_y: egen n_shoes_hh = total(shoes) 
bys hhid_y: egen n_adults_shoes = count(shoes) 
gen child_shoes = 1 if (n_shoes_hh >= n_adults_shoes*0.5)  & n_adults_shoes!=0 & age<16

* small money
bys hhid_y: egen n_small_money_hh = total(small_money) 
bys hhid_y: egen n_adults_small_moneys = count(small_money) 
gen child_small_money = 1 if (n_small_money_hh >= n_adults_small_moneys*0.5)  & n_adults_small_moneys!=0 & age<16

* leisure
bys hhid_y: egen n_leisure_hh = total(leisure) 
bys hhid_y: egen n_adults_leisure = count(leisure) 
gen child_leisure = 1 if (n_leisure_hh >= n_adults_leisure*0.5)  & n_adults_leisure!=0 & age<16

* friends
bys hhid_y: egen n_friends_hh = total(friends) 
bys hhid_y: egen n_adults_friends = count(friends) 
gen child_friends = 1 if (n_friends_hh >= n_adults_friends*0.5)  & n_adults_friends!=0 & age<16

* number of deprivations (out of 13)
egen n_deprivations_child = rowtotal(unexpfexp housing holiday protmeal warm car furniture child_internet child_clothes child_shoes child_small_money child_leisure child_friends),missing
replace n_deprivations_child=. if cases_excl==1


// MD for children
replace mat_deprived = 0 if  age<16
replace mat_deprived = 1 if (n_deprivations_child >=7 & child_n_deprivations_hh>=3) & age<16


** PERSISTENT MATERIAL DEPRIVATION **
gen mat_deprived_2018 = . if year==2018
replace mat_deprived_2018 = 1 if mat_deprived==1 & year==2018
replace mat_deprived_2018 = 0 if mat_deprived==0 & year==2018

gen mat_deprived_2019 = . if year==2019
replace mat_deprived_2019 = 1 if mat_deprived==1 & year==2019
replace mat_deprived_2019 = 0 if mat_deprived==0 & year==2019

gen mat_deprived_2020 = . if year==2020
replace mat_deprived_2020 = 1 if mat_deprived==1 & year==2020
replace mat_deprived_2020 = 0 if mat_deprived==0 & year==2020

gen mat_deprived_2021 = . if year==2021
replace mat_deprived_2021 = 1 if mat_deprived==1 & year==2021
replace mat_deprived_2021 = 0 if mat_deprived==0 & year==2021
 
// number of periods deprived
egen n_md_aux = rowtotal(mat_deprived_2018 mat_deprived_2019 mat_deprived_2020), missing
bys hid pid: egen n_mat_deprived = sum(n_md_aux)
*drop n_md_aux

// if the person is arop in the current year
bys hid pid: egen md_t = sum(mat_deprived_2021)
 
 // persistent MD
 gen persistent_mat_deprived = 0
replace persistent_mat_deprived = 1 if n_mat_deprived>=2 & md_t==1
 

*--------------------------------------------------------
* 5) Persistent AROP + Material Deprivation
*--------------------------------------------------------
  gen persistent_arop_md = 0
 replace persistent_arop_md = 1 if persistent_arop==1 & persistent_mat_deprived==1
 
 
 *--------------------------------------------------------
* 6) Roma population
*--------------------------------------------------------
 
qui merge m:1 rb030 using "$createddata\UDB_cBG21R_Ethnos.dta", keepusing(e1)
keep if _merge==3
drop _merge

// Roma
gen roma = 0
replace roma = 1 if e1==3
label var roma "Roma"

 
 *****************
 *** TABLE 13 ***
 *****************
 // variables re-expressed *100
 foreach var in persistent_arop persistent_mat_deprived persistent_arop_md {
		gen `var'_1 = `var' * 100
}

putexcel set "$tables\Table13", replace
putexcel A2 = "Persistent AROP"
putexcel A3 = "Persistent severe material and social deprivation (SMSD)"
putexcel A4 = "Persistent AROP + persistent SMSD"
putexcel B1 = "Bulgaria"
putexcel C1 = "Roma"

// Bulgaria
tabstat persistent_arop_1 [aw=wgt_long] if person==1, stat(mean) save 
putexcel B2 = matrix(r(StatTotal)), nformat(#.0)
tabstat persistent_mat_deprived_1 [aw=wgt_long] if person==1, stat(mean) save 
putexcel B3 = matrix(r(StatTotal)), nformat(#.0)
tabstat persistent_arop_md_1 [aw=wgt_long] if person==1, stat(mean) save 
putexcel B4 = matrix(r(StatTotal)), nformat(#.0)

 // Roma
tabstat persistent_arop_1 [aw=wgt_long] if person==1 & roma==1, stat(mean) save 
putexcel C2 = matrix(r(StatTotal)), nformat(#.0)
tabstat persistent_mat_deprived_1 [aw=wgt_long] if person==1  & roma==1, stat(mean) save 
putexcel C3 = matrix(r(StatTotal)), nformat(#.0)
tabstat persistent_arop_md_1 [aw=wgt_long] if person==1  & roma==1, stat(mean) save 
putexcel C4 = matrix(r(StatTotal)), nformat(#.0)

 
 
 *--------------------------------------------------------
* (Some of the) Annex Tables 					
*--------------------------------------------------------
 
// Creating variables for the regession analysis

* panel identifier, 1 obs per individual (and the obs is 2021 for all)
gen d_2021 = 0
replace d_2021 = 1 if year==2021

keep if year==2021

gen aux = 1
gen person_panel = 1 if d_2021==1 & aux==1

// hh tag
egen hh_level = tag(hhid_y)

// hh head 
gen hhead = 0
replace hhead = 1 if pid==hb070					// HB070: Person responding the hh questionnaire --> proxy of hh head

bys hhid_y: egen aux1 = sum(hhead)
gen flag1 = 1 if aux1==0
tab flag1 if hh_level==1									

bys hhid_y: g i=_n
replace hhead = 1 if i==1 & flag1==1				
replace hhead = 1 if i==1 & hb070==.
replace hhead = 0 if age<10
drop i flag1

// age hh head
gen hhead_age_aux = age if hhead==1
bys hhid_y: egen hhead_age=max(hhead_age_aux)
drop hhead_age_aux

// location 
* rural
recode db100 (1 2=1) (3=0), gen(urban)
label var urban "Urban"	

 * degree of urbanization: densely-populated area, intermediate area, thinly-populated area 
gen densely = db100==1 if ~missing(db100)       // cities
gen inter = db100==2 if ~missing(db100)		     // towns and suburbs
gen thinly = db100==3 if ~missing(db100)		    // rural areas
 
// regions
tab db040, gen(reg_BG)

// hh size
count if hx040==.
clonevar hhsize=hx040

// vulnerable hhs

* female headed
gen femalehead = (male==0 & hhead==1)
bys hhid_y: egen femaleheaded_hh=max(femalehead)

* hh with at least one unemployed
gen unemployed = 1 if pl032==2 
bys hhid_y: egen unemployed_hh=max(unemployed)
replace unemployed_hh = 0 if unemployed_hh==.

* single elderly household
gen elderly=(age>64)
gen single_elderly=0
replace single_elderly=1 if elderly==1 & hhsize==1
gen single_elderly_hh = single_elderly

// number and share of adults aged 18-64 (hh-level)
gen adult_18_64 = age>17 & age<65 & age<.
bys hhid_y: egen n_adult_18_64 = total(adult_18_64)
gen double sh_adult_18_64=n_adult_18_64/hhsize
drop adult_18_64

// number and share of children
gen children_0_18 = age<18 & age<.
bys hhid_y: egen n_children_0_18 = total(children_0_18)
gen double sh_children_0_18=n_children_0_18/hhsize
drop children_0_18

// number and share of elderly
gen adults_65 = age>64 & age<.
bys hhid_y: egen n_adults_65 = total(adults_65)
gen double sh_adults_65=n_adults_65/hhsize
drop adults_65

// household type: child, adult, old
gen adult=age>15 & age<.
gen child=(age<=15 & age!=.)
gen old=(age>64 & age!=.)
gen workage=(age>15 & age<=64)
bys hhid_y: egen n_child=total(child)
bys hhid_y: egen n_old = total(old)
bys hhid_y: egen n_adult = total(adult)
	
gen double sh_childold=(n_child+n_old)/hx040
gen double sh_child=n_child/hx040
gen double sh_old=n_old/hx040

* hh with 3 or more children
gen hh_3more_children=0
replace hh_3more_children=1 if n_children_0_18>=3

* hh with children < 6 years old
gen child_06=(age<6)
bys hhid_y: egen hh_child_06=max(child_06)

* hh with 5 or more members
gen hh_5members = 0
replace hh_5members=1 if hhsize>4 

* hh with disabled
gen disabled = (py130g>0)
bys hhid_y: egen disabled_hh=max(disabled)

* hh with pensioner
gen pensioner = (py100g>0)
replace pensioner = 0 if missing(py100g)
cap drop pensioner_hh
bys hhid_y: egen pensioner_hh=max(pensioner)

* hh with social aid (HY060N - Social exclusion not elsewhere classified)
gen socialaid = 0
replace socialaid=1 if hy060n>0 & hy060n!=.
tab socialaid 
bys hhid_y: egen socialaid_hh=max(socialaid)

// tenure status of the hh head
recode hh021 (1 2=1) (3 4 5=0), gen(owner)
label var owner "house owner"	

gen owner_hhead_aux = owner if hhead==1
bys hhid_y: egen owner_hhead=max(owner_hhead_aux)
drop owner_hhead_aux

// education level (pe040: highest ISCED level attained)
gen edu=.
replace edu= 1 if pe041==0 & year>=2021  											//Less primary
replace edu= 1 if inrange(pe041,100,200) & year>=2021 					//Completed primary
replace edu= 2 if inrange(pe041,340,490) & year>=2021 					//Completed secondary
replace edu= 3 if inrange(pe041,500,800) & year>=2021 					//Tertiary

label def edu  1"primary educ" 2"secondary educ" 3"tertiary educ"
label values edu edu

// education level of the hh head
gen edu_hhead_aux = edu if hhead==1
bys hhid_y: egen edu_hhead=max(edu_hhead_aux)
bys hhid_y: egen edu_hhead2=max(edu)
drop edu_hhead_aux

/* flag: there are many missings in the original variable */
replace edu_hhead=edu_hhead2 if edu_hhead==.
drop edu_hhead2

label def edu_hhead  1"primary educ" 2"secondary educ" 3"tertiary educ"
label values edu_hhead edu_hhead

// labor force status
gen lfstat1=. 

//changed from PL031 to PL032 in 2021 and also the values
ta pl032,m 
			 replace lfstat1=1 if (pl032==1) & year>=2009 & year>=2021 // employee working full-time, employee working part-time, self-employed full time, self-employed part time
             replace lfstat1=2 if pl032==2 & year>=2009 & year>=2021 // unemployed
             replace lfstat1=3 if pl032==3 & year>=2009 & year>=2021 // retired
             replace lfstat1=4 if (pl032==4|pl032==6|pl032==7|pl032==8) & year>=2009 & year>=2021 // long-term disability, military/community or service, care responsibilities, other inactive person
             replace lfstat1=5 if pl032 ==5  & year>=2009 & year>=2021 // student

				replace lfstat1=. if age<=15
				recode lfstat1 (1=1)(2=2)(3=3)(4=4)(5=5)(.=.), gen(lfstat)
				label define lfstat 1 "Employed" 2"Unemployed" 3"Retired" 4"Inactive" 5"Student"
                label values lfstat lfstat

// labor force status of the hh head
gen lfstat_hhead_aux = lfstat if hhead==1
bys hhid_y: egen lfstat_hhead=max(lfstat_hhead_aux)
drop lfstat_hhead_aux

label define lfstat_hhead 1 "Employed" 2"Unemployed" 3"Retired" 4"Inactive" 5"Student"
label values lfstat_hhead

// crowding index (average number of people per room available to the household) > 2 (HH030) 
gen pers_room = hhsize/hh030
gen crowding = .
replace crowding = 1 if pers_room>2
replace crowding = 0 if pers_room<=2


*******************
*** Table A4.10 ***
*******************
* rounding the weight
gen weight_round = round(wgt_long)


// label vars
label var male "male"
label var age "age"
label var owner_hhead "home ownership"
label var  crowding "overcrowded house"
label var  n_children_0_18 "number of individuals <18"
label var  n_adult_18_64 "number of individuals 18-64"
label var  n_adults_65 "number of individuals >64"
label  var femaleheaded_hh "female headed hh"
label var  unemployed_hh "hh with unemployed"
label var  single_elderly_hh "single-elderly hh"
label var  hh_3more_children "hh with 3 or more children"
label var   hh_5members "hh with 5 or more members"
label var  disabled_hh "hh with disability recipient"
label var  pensioner_hh "hh with pensioner"
label var  socialaid_hh "hh with social aid"
label var  inter "towns and suburbs"
label var  thinly " rural areas"


// regression	
foreach depvar in persistent_arop persistent_mat_deprived persistent_arop_md  {
	
		probit `depvar' male age ///
								owner_hhead i.edu_hhead i.lfstat_hhead ///
								crowding ///
								n_children_0_18 n_adult_18_64 n_adults_65 ///
								roma ///
								femaleheaded_hh unemployed_hh single_elderly_hh hh_3more_children hh_5members disabled_hh pensioner_hh socialaid_hh ///			
								inter thinly ///
								reg_BG1 reg_BG2 if person_panel==1  [w=weight_round], robust			
		local r2_p= e(r2_p)
		margins, dydx(*) post	
		outreg2 using "$tables\TableA4-10.xls", append ctitle(`depvar')  bdec(3)  label  addstat(Pseudo R-squared, `r2_p')
}


 
 